@@ -432,9 +432,6 @@ class WebDriver (ElementLocation):
     def back(self):
         return self.driver.back()
 
-    def create_web_element(self,element_id):
-        return self.driver.create_web_element(element_id)
-
     def delete_all_cookies(self):
         return self.driver.delete_all_cookies()
 
@@ -447,14 +444,20 @@ class WebDriver (ElementLocation):
     def download_file(self,file_name,target_directory):
         return self.driver.download_file(file_name,target_directory)
 
-    def execute(self,driver_command,params=None):
-        return self.driver.execute(driver_command,params)
+    #def execute(self,driver_command,params=None):
+    #    return self.driver.execute(driver_command,params)
 
     def execute_async_script(self,script: str, *args):
-        return self.driver.execute_async_script(script,args)
+        theseWebElems=[]
+        for arg in args:
+            theseWebElems.append(arg.webElement)
+        return self.driver.execute_async_script(script,theseWebElems)
 
     def execute_script(self,script, *args):
-        return self.driver.execute_script(script,args)
+        theseWebElems=[]
+        for arg in args:
+            theseWebElems.append(arg.webElement)
+        return self.driver.execute_script(script,theseWebElems)
 
     def forward(self):
         return self.driver.forward()
